# coding: utf-8

"""
    Jupyter Server API

    Server API

    The version of the OpenAPI document: 5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from nbserv_client.models.kernel_spec_file_help_links_inner import KernelSpecFileHelpLinksInner
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class KernelSpecFile(BaseModel):
    """
    Kernel spec json file
    """ # noqa: E501
    language: StrictStr = Field(description="The programming language which this kernel runs. This will be stored in notebook metadata.")
    argv: List[StrictStr] = Field(description="A list of command line arguments used to start the kernel. The text `{connection_file}` in any argument will be replaced with the path to the connection file.")
    display_name: StrictStr = Field(description="The kernel's name as it should be displayed in the UI. Unlike the kernel name used in the API, this can contain arbitrary unicode characters.")
    codemirror_mode: Optional[StrictStr] = Field(default=None, description="Codemirror mode.  Can be a string *or* an valid Codemirror mode object.  This defaults to the string from the `language` property.")
    env: Optional[Dict[str, StrictStr]] = Field(default=None, description="A dictionary of environment variables to set for the kernel. These will be added to the current environment variables.")
    help_links: Optional[List[KernelSpecFileHelpLinksInner]] = Field(default=None, description="Help items to be displayed in the help menu in the notebook UI.")
    __properties: ClassVar[List[str]] = ["language", "argv", "display_name", "codemirror_mode", "env", "help_links"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of KernelSpecFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in help_links (list)
        _items = []
        if self.help_links:
            for _item in self.help_links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['help_links'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of KernelSpecFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "language": obj.get("language"),
            "argv": obj.get("argv"),
            "display_name": obj.get("display_name"),
            "codemirror_mode": obj.get("codemirror_mode"),
            "env": obj.get("env"),
            "help_links": [KernelSpecFileHelpLinksInner.from_dict(_item) for _item in obj.get("help_links")] if obj.get("help_links") is not None else None
        })
        return _obj


